import express from "express";
import bodyParser from "body-parser";
import morgan from "morgan";
import cors from "cors";
import cookieParser from "cookie-parser";
import api from "./routes/api.js";
// import { MongoManager } from "./mongo/mongoManager.js";
import proxy from "express-http-proxy";
import config from "./config/config.js";
const router = express.Router();
import * as path from "path";
import { fileURLToPath } from "url";
import { dirname } from "path";

const __filename = fileURLToPath(import.meta.url);
const __dirname = dirname(__filename);

// const mongoManager = new MongoManager(config);

const logger = morgan;

const app = express();
const port = process.env.PORT || 3000;

/**
 * Connects to MongoDB
 */
// mongoManager.connect();

// Middleware to parse JSON requests
app.use(bodyParser.json());
app.use(logger("dev"));
app.use(express.json());
app.use(cors());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser());
// Serve Angular frontend static files before any other routes
app.use(express.static(path.join(__dirname, "../frontend/dist/frontend")));

// Mount your routes
app.use("/", api);

/**
 * For non registered route
 */
app.use("/", function (req, res, next) {
  res.sendFile(path.join(__dirname, "../frontend/dist/frontend", "index.html"));
});

// error handler
app.use(function (err, req, res, next) {
  // set locals, only providing error in development
  res.locals.message = err.message;
  res.locals.error = req.app.get("env") === "development" ? err : {};

  // render the error page
  res.status(err.status || 500);
  res.render("error");
});

// Catch-all to serve Angular's index.html for unmatched routes
app.get("*", (req, res) => {
  res.sendFile(path.join(__dirname, "../frontend/dist/frontend", "index.html"));
});

// Start the server
app.listen(port, () => {
  console.log(`Server is running on port ${port}`);
});
