import axios from "axios";
import { APIError } from "rest-api-errors";
import { Country } from "../models/country.js"; // Assuming you have a Country model

export const fetchCountries = async (authorizationToken, username) => {
    try {
        // Ensure you have the right URL and that your server is reachable
        console.log("URL being requested:", `${process.env.SWAGGER_URL}/master/country/country-list`);

        const response = await axios.get(`${process.env.SWAGGER_URL}/master/country/country-list`, {
            headers: {
                Authorization: authorizationToken,
                Accept: "application/json",
                username: username,
            },
        });

        // Log the response for debugging
        console.log("Response data:", response.data);
        
        return response.data;
    } catch (error) {
        console.error("Error occurred:", error.response || error.message || error);
        throw new APIError(
            error?.response?.status,
            error?.response?.status?.toString(),
            error?.response?.statusText
        );
    }
};


export const getCountry = async (countryID, authorizationToken, username) => {
  try {
      const url = `${process.env.SWAGGER_URL}/master/country/country?countryID=${countryID}`;
      console.log("URL being requested:", url);

      const response = await axios.get(url, {
          headers: {
              Authorization: authorizationToken,
              Accept: "application/json",
              username: username,
          },
      });

      console.log("Response data:", response.data);
      
      return response.data;
  } catch (error) {
      console.error("Error occurred:", error.response || error.message || error);
      throw new APIError(
          error?.response?.status,
          error?.response?.status?.toString(),
          error?.response?.statusText
      );
  }
};


export const fetchCurrencies = async (authorizationToken, username) => {
  try {
      // Ensure you have the right URL and that your server is reachable
      console.log("URL being requested:", `${process.env.SWAGGER_URL}/master/country/add/currency-list`);

      const response = await axios.get(`${process.env.SWAGGER_URL}/master/country/add/currency-list`, {
          headers: {
              Authorization: authorizationToken,
              Accept: "application/json",
              username: username,
          },
      });

      // Log the response for debugging
      console.log("Response data:", response.data);
      
      return response.data;
  } catch (error) {
      console.error("Error occurred:", error.response || error.message || error);
      throw new APIError(
          error?.response?.status,
          error?.response?.status?.toString(),
          error?.response?.statusText
      );
  }
};



export const getInternationalTransaction = async (authorizationToken, username) => {
  try {
      // Ensure you have the right URL and that your server is reachable
      console.log("URL being requested:", `${process.env.SWAGGER_URL}/master/country/add/international-transaction-type-list`);

      const response = await axios.get(`${process.env.SWAGGER_URL}/master/country/add/international-transaction-type-list`, {
          headers: {
              Authorization: authorizationToken,
              Accept: "application/json",
              username: username,
          },
      });

      // Log the response for debugging
      console.log("Response data:", response.data);
      
      return response.data;
  } catch (error) {
      console.error("Error occurred:", error.response || error.message || error);
      throw new APIError(
          error?.response?.status,
          error?.response?.status?.toString(),
          error?.response?.statusText
      );
  }
};


export const addCountry = async (countryData) => {
  try {
    const response = await axios.post(`${process.env.SWAGGER_URL}/master/country/Insert`, countryData);
    return response.data;
  } catch (error) {
    throw new APIError(error?.response?.status, `${error?.response?.status}`, error?.response?.statusText);
  }
};

export const updateCountry = async (countryId, updateData) => {
  try {
    const response = await axios.patch(`${process.env.SWAGGER_URL}/master/country/Update/${countryId}`, updateData);
    return response.data;
  } catch (error) {
    throw new APIError(error?.response?.status, `${error?.response?.status}`, error?.response?.statusText);
  }
};

// Add more functions here as needed for the remaining endpoints

// Note: Make sure to replace `${process.env.SWAGGER_URL}` with your actual environment variable if different.
