import { Component, OnInit } from '@angular/core';
import { ComplianceReportService } from '../services/compliance-report.service';

@Component({
  selector: 'app-compliance-report',
  templateUrl: './compliance-report.component.html',
  styleUrls: ['./compliance-report.component.css'],
})
export class ComplianceReportComponent implements OnInit {
  filterData: any[] = [];
  complianceReportData: any[] = [];

  fromDate: string = new Date().toISOString().substring(0, 10); // Initialize with current date
  toDate: string = new Date().toISOString().substring(0, 10); 
  isLoading: boolean = false;

  selectedFilter: any;

  constructor(private complianceService: ComplianceReportService) {}

  ngOnInit() {
    this.loadFilterData();
  }

  loadFilterData() {
    this.isLoading = true;

    this.complianceService.getComplianceReportFilteredData().subscribe(
      (data: any[]) => {
        this.filterData = data;
        this.selectedFilter = this.filterData?.[0]?.ID;
        this.isLoading = false;
      },
      (error) => {
        console.error(error);
        this.isLoading = false;
      }
    );
  }

  onFilterChange(event: any) {
    const selectedId = event.target.value;
    this.selectedFilter = selectedId;
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  // loadComplianceReportData() {
  //   if (!this.fromDate || !this.toDate) {
  //     alert('Please select both start date and end date.');
  //     return;
  //   }

  //   const fromDateObj = new Date(this.fromDate);
  //   const toDateObj = new Date(this.toDate);

  //   if (toDateObj < fromDateObj) {
  //     alert('End date cannot be before start date.');
  //     return;
  //   }

  //   const formattedFromDate = fromDateObj.toISOString().split('T')[0];
  //   const formattedToDate = toDateObj.toISOString().split('T')[0];

  //   this.isLoading = true;

  //   this.complianceService
  //     .getAllComplianceReportRecords(
  //       this.selectedFilter,
  //       formattedFromDate,
  //       formattedToDate
  //     )
  //     .subscribe(
  //       (data: any[]) => {
  //         if (data.length == 0) {
  //           alert('No data found.');
  //           this.complianceReportData = [];
  //           this.isLoading = false;
  //           return;
  //         }
  //         this.complianceReportData = data;
  //         this.isLoading = false;
  //       },
  //       (error) => {
  //         console.error(error);
  //         this.isLoading = false;
  //       }
  //     );
  // }
  loadComplianceReportData() {
    if (!this.fromDate || !this.toDate) {
      alert('Please select both start date and end date.');
      return;
    }
  
    const fromDateObj = new Date(this.fromDate);
    const toDateObj = new Date(this.toDate);
  
    if (toDateObj < fromDateObj) {
      alert('End date cannot be before start date.');
      return;
    }
  
    const formattedFromDate = fromDateObj.toISOString().split('T')[0];
    const formattedToDate = toDateObj.toISOString().split('T')[0];
  
    this.isLoading = true;
  
    this.complianceService
      .getAllComplianceReportRecords(
        this.selectedFilter,
        formattedFromDate,
        formattedToDate
      )
      .subscribe(
        (data: any[]) => {
          if (data.length == 0) {
            alert('No data found.');
            this.complianceReportData = [];
            this.isLoading = false;
            return;
          }
  
          // Sort the data by PayinDate in descending order
          this.complianceReportData = data.sort((a, b) => {
            return new Date(b.PayinDate).getTime() - new Date(a.PayinDate).getTime();
          });
  
          this.isLoading = false;
        },
        (error) => {
          console.error(error);
          this.isLoading = false;
        }
      );
  }
  
}
