import { Component, OnInit } from '@angular/core';
import { MisReportService } from '../services/mis-report.service';

@Component({
  selector: 'app-mis-report',
  templateUrl: './mis-report.component.html',
  styleUrls: ['./mis-report.component.css'],
})
export class MisReportComponent implements OnInit {
  reportTypes: any[];
  sendCountries: any[];
  selectedSendCountry: number = -1;
  sendAgents: any[];
  receiveCountries: any[];
  selectedReceiveCountry: number = -1;
  receiveAgents: any[];

  fromDate: string;
  toDate: string;

  constructor(private misReportService: MisReportService) {}

  ngOnInit(): void {
    this.initializeDates();
    this.loadReportTypes();
    this.loadSendCountries();
    this.loadReceiveCountries();
  }

  initializeDates(): void {
    const today = new Date();
    const yyyy = today.getFullYear();
    const mm = String(today.getMonth() + 1).padStart(2, '0');
    const dd = String(today.getDate()).padStart(2, '0');

    this.fromDate = `${yyyy}-${mm}-${dd}`;
    this.toDate = `${yyyy}-${mm}-${dd}`;
  }

  loadReportTypes() {
    this.misReportService.getReportTypes().subscribe((reports) => {
      this.reportTypes = reports;
    });
  }

  loadSendCountries() {
    this.misReportService.getSendCountries().subscribe((countries) => {
      this.sendCountries = countries;
      this.loadSendAgents(31);
    });
  }

  onSendCountryChange(countryId: number) {
    this.selectedSendCountry = countryId;
    this.loadSendAgents(countryId);
  }

  loadSendAgents(countryId: number) {
    this.misReportService.getSendAgents(countryId).subscribe((agents) => {
      this.sendAgents = agents;
    });
  }

  loadReceiveCountries() {
    this.misReportService.getReceiveCountries().subscribe((countries) => {
      this.receiveCountries = countries;
      this.loadReceiveAgents(119);
    });
  }

  onReceiveCountryChange(countryId: number) {
    this.selectedReceiveCountry = countryId;
    this.loadReceiveAgents(countryId);
  }

  loadReceiveAgents(countryId: number) {
    this.misReportService.getReceiveAgents(countryId).subscribe((agents) => {
      this.receiveAgents = agents;
    });
  }
}
