import { Component, ViewChild, TemplateRef } from '@angular/core';
import { BsModalService, BsModalRef } from 'ngx-bootstrap/modal';
import { FormBuilder } from '@angular/forms';
import { RejectedCustomerService } from '../rejected-customer.service';
import { AuthService } from '../services/auth.service';
import { EditCustomerRegistrationService } from '../services/edit-customer-registration.service';
import { getCacheData } from '../utils/helper';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-rejected-customer',
  templateUrl: './rejected-customer.component.html',
  styleUrls: ['./rejected-customer.component.css'],
})
export class RejectedCustomerComponent {
  bsModalRef: BsModalRef;

  @ViewChild('editCustomerRegistration')
  editCustomerRegistrationTemplate: TemplateRef<any>;
  selectedSearchOption: any = 4;
  customerNumber: string = '';
  firstName: string = '';
  fromDate: string = '';
  toDate: string = '';
  editedCustomer: any = {};
  isLoading: boolean = false;

  allData: any;
  occupationList: any;
  nationalityList: any;
  productTypeList: any;
  idTypeList: any;
  sourceList: any;

  genderList: any = [
    {
      id: 'M',
      value: 'Male',
    },
    {
      id: 'F',
      value: 'Female',
    },
  ];

  statusList: any = [
    {
      id: 1,
      value: 'Active',
    },
    {
      id: 0,
      value: 'InActive',
    },
  ];
  constructor(
    private modalService: BsModalService,
    private fb: FormBuilder,
    private RejectedCustomerSvc: RejectedCustomerService,
    private editCustomerRegistrationSvc: EditCustomerRegistrationService,
    private authSvc: AuthService,
    private toastrSvc: ToastrService

  ) {
    this.createForm();
  }

  ngOnInit() {
    this.fromDate = this.authSvc.getTodayDate();
    this.toDate = this.authSvc.getTodayDate();
    this.search();
  }

  createForm() { }

  search() {
    if (this.selectedSearchOption == 5 && !this.customerNumber) {
      alert('Please Enter Customer No.');
      return;
    }

    if (this.selectedSearchOption == 6 && !this.firstName) {
      alert('Please Enter First Name.');
      return;
    }

    if (this.selectedSearchOption == 7 && !this.fromDate) {
      alert('Please Select From Date.');
      return;
    }

    if (this.selectedSearchOption == 7 && !this.toDate) {
      alert('Please Select To Date.');
      return;
    }

    if (this.selectedSearchOption == 5) {
      this.isLoading = true;
      this.fromDate = '';
      this.toDate = '';
      this.RejectedCustomerSvc.getCustomer(
        this.selectedSearchOption,
        this.fromDate,
        this.toDate,
        this.customerNumber
      ).subscribe((res: any) => {
        if (res?.length == 0) {
          this.isLoading = false;
          alert('No data found.');
          return;
        }
        this.allData = res;
        this.isLoading = false;
      });
    }
    if (this.selectedSearchOption == 4) {
      this.fromDate = '';
      this.toDate = '';

      this.RejectedCustomerSvc.getCustomer(
        this.selectedSearchOption,
        this.fromDate,
        this.toDate,
        this.firstName
      ).subscribe((res: any) => {
        if (res?.length == 0) {
          this.isLoading = false;
          alert('No data found.');
          return;
        }
        this.allData = res;
        this.isLoading = false;
      });
    }
    if (this.selectedSearchOption == 6) {
      this.fromDate = '';
      this.toDate = '';

      this.RejectedCustomerSvc.getCustomer(
        this.selectedSearchOption,
        this.fromDate,
        this.toDate,
        this.firstName
      ).subscribe((res: any) => {
        if (res?.length == 0) {
          this.isLoading = false;
          alert('No data found.');
          return;
        }
        this.allData = res;
        this.isLoading = false;
      });
    }
    if (this.selectedSearchOption == 7) {
      this.isLoading = true;
      this.RejectedCustomerSvc.getCustomer(
        this.selectedSearchOption,
        this.fromDate,
        this.toDate,
        ''
      ).subscribe((res: any) => {
        if (res?.length == 0) {
          this.isLoading = false;
          alert('No data found.');
          return;
        }
        this.allData = res;
        this.isLoading = false;
      });
    }
  }

  editRejectedCustomer(item) {
    this.bsModalRef = this.modalService.show(
      this.editCustomerRegistrationTemplate,
      { class: 'modal-lg' }
    );
    this.edit(item);
    this.getOccupationList();
    this.getNationalityList();
    this.getProductTypeList();
    this.getSourceList();
    this.getIdTypeList();
  }

  // updateCustomer() {
  //   console.log('Update Customer method called.');

  //   this.bsModalRef.hide();
  // }

  getOccupationList() {
    this.RejectedCustomerSvc.getOccupationList().subscribe({
      next: (res: any) => {
        this.occupationList = res;
      },
      error: (err) => {
        this.occupationList = [];
      },
      complete: () => { },
    });
  }

  getNationalityList() {
    this.RejectedCustomerSvc.getNationalityList().subscribe({
      next: (res: any) => {
        this.nationalityList = res;
      },
      error: (err) => {
        this.nationalityList = [];
      },
      complete: () => { },
    });
  }

  getProductTypeList() {
    this.RejectedCustomerSvc.getProductTypeList().subscribe({
      next: (res: any) => {
        this.productTypeList = res;
      },
      error: (err) => {
        this.productTypeList = [];
      },
      complete: () => { },
    });
  }

  getIdTypeList() {
    this.RejectedCustomerSvc.getIdTypeList().subscribe({
      next: (res: any) => {
        this.idTypeList = res?.[0]?.IDType;
      },
      error: (err) => {
        this.idTypeList = [];
      },
      complete: () => { },
    });
  }
  getSourceList() {
    this.RejectedCustomerSvc.getSourceList().subscribe({
      next: (res: any) => {
        this.sourceList = res;
      },
      error: (err) => {
        this.sourceList = [];
      },
      complete: () => { },
    });
  }

  edit(item) {
    this.RejectedCustomerSvc.Edit(item).subscribe((res) => {
      this.editedCustomer = res[0];
      this.editedCustomer.Gender = this.editedCustomer.Gender.trim();
      this.editedCustomer.DateOfBirth = this.formatDate(
        this.editedCustomer?.DateOfBirth
      );
      this.editedCustomer.RegDateTime = this.formatDate(
        this.editedCustomer?.RegDateTime
      );
      this.editedCustomer.IDExpiryDate = this.formatDate(
        this.editedCustomer?.IDExpiryDate
      );
    });
  }

  formatDate(inputDate: string): string {
    // Split the inputDate into parts (assuming it is in the format MM/dd/yyyy)
    let dateParts = inputDate.split('/');

    // Create a new Date object using the parts
    let formattedDate = new Date(
      `${dateParts[2]}-${dateParts[0]}-${dateParts[1]}`
    );

    // Format the date as "yyyy-MM-dd"
    return formattedDate.toISOString().split('T')[0];
  }

  updateCustomer(item) {
    if (!item?.CustomerNo) {
      alert('Please Fill Customer No.');
      return;
    }

    if (!item?.FirstName) {
      alert('Please Fill First Name.');
      return;
    }

    if (!item?.LastName) {
      alert('Please Fill Last Name.');
      return;
    }

    const selectedNationality = this.nationalityList.find(
      (p) => p.NShortName === item.Nationality
    );

    if (!selectedNationality) {
      alert('Please Select Nationality.');
      return;
    }

    if (!item?.IDNumber) {
      alert('Please Fill ID Number.');
      return;
    }

    if (!item?.IDExpiryDate) {
      alert('Please Select ID Expiry Date.');
      return;
    }

    const selectedOccupation = this.occupationList.find(
      (p) => p.OccupationID === Number(item.Occupation)
    );

    if (!selectedOccupation) {
      alert('Please Select Occupation.');
      return;
    }

    if (!item?.CustomerAccountNo) {
      alert('Please Fill Customer Account No.');
      return;
    }

    if (!item?.DateOfBirth) {
      alert('Please Fill Date of Birth.');
      return;
    }

    if (!item?.Telephone) {
      alert('Please Fill Telephone.');
      return;
    }

    if (!item?.EasyPayExpiryDate) {
      alert('Please Fill Easy Pay Expiry Date.');
      return;
    }

    if (!item?.BirthCountry) {
      alert('Please Fill Birth Country.');
      return;
    }

    if (!item?.TotalMonthlyIncome) {
      alert('Please Fill Total Monthly Income.');
      return;
    }

    if (!item?.RegDateTime) {
      alert('Please Fill Registrations Date Time.');
      return;
    }

    if (!item?.City) {
      alert('Please Fill City.');
      return;
    }

    let payload;
    payload = {
      CustomerNo: item.CustomerNo,
      FirstName: item.FirstName,
      LastName: item.LastName,
      CustomerAddress: item.Address,
      Nationality: item.Nationality,
      producttype: item.ProductType,
      Gender: item.Gender,
      Idnumber: item.IDNumber,
      Idexpirydate: item.IDExpiryDate,
      Occupation: String(item.Occupation),
      BirthCountry: item.BirthCountry,
      TotalMonthlyIncome: item.TotalMonthlyIncome,
      MiddleName: item.MiddleName,
      customertype: String(item.CustomerTypeName),
      EasyPayExpriyDate: item.EasyPayExpiryDate,
      CustomerAccountNo: item.CustomerAccountNo,
      dob: item.DateOfBirth,
      telephone: item.Telephone,
      IDtype: item.IDType,
      RegDateTime: item.RegDateTime,
      City: item.City,
      Sourceoffund: String(item.SourceOfFund),
      Status: String(item.IsActive),
      UserID: getCacheData('G_UserID'),
    };
    this.editCustomerRegistrationSvc
      .updateCustomerRegistration(payload)
      .subscribe({
        next: (res: any) => {
          if (res) {
            this.bsModalRef.hide();
            // alert('Customer details updated successfully.');
            this.toastrSvc.success('Customer details updated successfully.');
            return;
          }
        },
        error: (err) => {
          this.bsModalRef.hide();
          // alert(err?.error?.message);
          this.toastrSvc.error(err?.error?.message);
        },
        complete: () => {
          this.bsModalRef.hide();
        },
      });
  }

  searchCustomer() {
    if (!this.editedCustomer.CustomerNo) {
      alert('Please Fill Customer Number!');
      return;
    }
    this.editCustomerRegistrationSvc
      .getSearchByCustomerNumber(this.editedCustomer.CustomerNo)
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            alert('No Data Found.');
            return;
          }
          this.mapCustomerDetails(res?.[0]);
        },
        error: (err) => { },
        complete: () => { },
      });
  }

  mapCustomerDetails(customer: any) {
    if (customer) {
      const cusGender = customer?.Gender.trim();
      const gender = this.genderList.find((g) => g.id == cusGender)?.id;

      this.editedCustomer = customer;
      this.editedCustomer.Gender = gender;
      this.editedCustomer.DateOfBirth = this.formatDate(
        this.editedCustomer?.DateOfBirth
      );
      this.editedCustomer.RegDateTime = this.formatDate(
        this.editedCustomer?.RegDateTime
      );
      this.editedCustomer.IDExpiryDate = this.formatDate(
        this.editedCustomer?.IDExpiryDate
      );
    }
  }

  resetForm() {
    console.log('Reset Form method called.');
    this.editedCustomer = {};
  }
  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
