import { Component, OnInit } from '@angular/core';
import { BeneficiaryComplianceReleaseReportRejectService } from '../services/beneficiary-compliance-release-report-reject.service';
import { RejectReportService } from '../services/reject-report.service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-release-beneficiary-compliance-reject',
  templateUrl: './release-beneficiary-compliance-reject.component.html',
  styleUrls: ['./release-beneficiary-compliance-reject.component.css'],
})
export class ReleaseBeneficiaryComplianceRejectComponent implements OnInit {
  beneficiaryDetails: any[] = [];
  beneficiaryNumber: string = '';
  isLoading: boolean = false;
  showNoDataAlert: boolean = false; // Flag to control alert visibility

  constructor(
    private releaseService: BeneficiaryComplianceReleaseReportRejectService,
    private rejectReportService: RejectReportService,
    private router: Router
  ) {}

  ngOnInit() {
    this.getStatusRecords();
  }

  navigateToBeneficiary(beneficiaryNumber: any) {
    this.router.navigate([
      `/panel/beneficiary-compliance-release-report/${beneficiaryNumber}`,
    ]);
  }

  onBeneficiaryNumberChange(value: string) {
    this.beneficiaryNumber = value;
  }

  searchBeneficiary() {
    if (this.beneficiaryNumber.trim() !== '') {
      this.isLoading = true;
      this.releaseService.getAllRecords(this.beneficiaryNumber).subscribe(
        (response: any) => {
          this.beneficiaryDetails = response;
          this.isLoading = false;
          if (this.beneficiaryDetails.length === 0) {
            this.showNoDataAlert = true; // Show alert when no data is returned
          } else {
            this.showNoDataAlert = false;
          }
        },
        (error) => {
          console.error('Error fetching beneficiary details:', error);
          this.beneficiaryDetails = [];
          this.isLoading = false;
          this.showNoDataAlert = true; // Show alert on error
        }
      );
    } else {
      console.log('Please enter a beneficiary number');
      this.beneficiaryDetails = [];
      this.showNoDataAlert = true; // Show alert when no beneficiary number is entered
    }
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  getStatusRecords() {
    this.isLoading = true;
    this.releaseService.getStatusRecords('Reject').subscribe(
      (response: any[]) => {
        this.beneficiaryDetails = response;
        this.isLoading = false;
        if (this.beneficiaryDetails.length === 0) {
          this.showNoDataAlert = true; // Show alert when no data is returned
        } else {
          this.showNoDataAlert = false;
        }
      },
      (error) => {
        console.error('Error fetching beneficiary details:', error);
        this.beneficiaryDetails = [];
        this.isLoading = false;
        this.showNoDataAlert = true; // Show alert on error
      }
    );
  }

  getOfacLogDetails(transactionNumber: string) {
    this.releaseService.complicanceOfacLogDetails(transactionNumber).subscribe(
      (response: any) => {
        console.log('OFAC Log Details:', response);
      },
      (error) => {
        console.error('Error fetching OFAC Log Details:', error);
      }
    );
  }

  closeAlert() {
    this.showNoDataAlert = false; // Method to close the alert
  }
}
