import { Component, OnInit } from '@angular/core';
import { SalesMarketingReportService } from '../services/sales-marketing-report.service';
import { MisReportService } from '../services/mis-report.service';

@Component({
  selector: 'app-sales-marketing-report',
  templateUrl: './sales-marketing-report.component.html',
  styleUrls: ['./sales-marketing-report.component.css'],
})
export class SalesMarketingReportComponent implements OnInit {
  reportTypes: any[];
  selectedReport: any;
  sendCountries: any[];
  selectedSendCountry: any;
  sendAgents: any = [];
  receiveCountries: any[];
  selectedReceiveCountry: any;
  criteria: any = [
    {
      id: 'Sending Agents Wise',
      value: '--Sending Agents Wise--',
    },
    {
      id: 'Receiving Agents Wise',
      value: '--Receiving Agents Wise--',
    },
  ];
  selectedCriteria: any = 'Sending Agents Wise';
  agentBranches: any = [];
  selectedAgentBranch: any;

  fromDate: string;
  toDate: string;

  constructor(
    private misReportService: MisReportService,
    private salesMarketingService: SalesMarketingReportService
  ) {}

  ngOnInit(): void {
    this.initializeDates();
    this.loadReportTypes();
    this.loadSendCountries();
    this.loadReceiveCountries();
  }

  initializeDates(): void {
    const today = new Date();
    const yyyy = today.getFullYear();
    const mm = String(today.getMonth() + 1).padStart(2, '0'); // Months are zero-based
    const dd = String(today.getDate()).padStart(2, '0');

    this.fromDate = `${yyyy}-${mm}-${dd}`;
    this.toDate = `${yyyy}-${mm}-${dd}`;
  }

  loadReportTypes() {
    this.salesMarketingService.getReportTypes().subscribe((reports) => {
      this.reportTypes = reports;
      this.selectedReport = this.reportTypes?.[0]?.Reports;
    });
  }

  loadSendCountries() {
    this.misReportService.getSendCountries().subscribe((countries) => {
      this.sendCountries = countries;
      this.selectedSendCountry = this.sendCountries?.[0]?.CountryID;
      this.loadSendAgents(
        this.sendCountries?.[0]?.CountryID,
        this.selectedCriteria
      );
    });
  }

  onSendCountryChange(countryId: number) {
    this.selectedSendCountry = countryId;
    this.loadSendAgents(countryId, this.selectedCriteria);
  }

  loadSendAgents(countryId: number, criteria: string) {
    this.salesMarketingService
      .getSendAgents(countryId, criteria)
      .subscribe((agents) => {
        this.sendAgents =
          agents.length > 0 ? agents : [{ Agent_Name: 'Agent Not Found' }];
      });
  }

  loadReceiveCountries() {
    this.misReportService.getReceiveCountries().subscribe((countries) => {
      this.receiveCountries = countries;
      this.selectedReceiveCountry = this.receiveCountries?.[0]?.CountryID;
    });
  }

  loadAgentBranches(agentId: number) {
    this.salesMarketingService
      .getAgentBranches(agentId)
      .subscribe((branches) => {
        this.agentBranches =
          branches.length > 0
            ? branches
            : [{ AgentBranch_Name: 'Agent Branch Not Found' }];
      });
  }

  onReportChange(report: string) {
    this.selectedReport = report;
  }
}
