import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { environment } from 'src/environments/environment';
import { getCacheData } from '../utils/helper';

@Injectable({
  providedIn: 'root',
})
export class AgentService {
  url = environment.apiUrl;

  constructor(private http: HttpClient) {}

  getCountries(token: any, username, userId = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/country?userId=${userId}`,
      { headers: headers }
    );
  }

  getAgents(token: any, username, countryId = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/agent?CountryId=${countryId}`,
      { headers: headers }
    );
  }

  getAllAgents(
    token: any,
    username: any,
    countryId = 0,
    agentId = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/agent-all-record?CountryId=${countryId}&AgetId=${agentId}`,
      { headers: headers }
    );
  }

  getAgentTypeList(token: any, username: any): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/agent-type-list`,
      { headers: headers }
    );
  }

  getCountryInsert(token: any, username: any, agentId = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/agent-wise-country?AgentId=${agentId}`,
      { headers: headers }
    );
  }

  getCity(token: any, username: any, countryId = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/city?CountryId=${countryId}`,
      { headers: headers }
    );
  }

  getLocation(
    token: any,
    username: any,
    cityId = 0,
    countryId = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/location?CityId=${cityId}&CountryId=${countryId}`,
      { headers: headers }
    );
  }

  getAgentSettlementCurrency(token: any, username: any): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/agent-settlement-currency`,
      { headers: headers }
    );
  }

  getAgentCurrency(token: any, username: any, countryId = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/agent-currency?CountryId=${countryId}`,
      { headers: headers }
    );
  }

  getModeofPayment(token: any, username: any, countryId = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/mode-of-payment?CountryId=${countryId}`,
      { headers: headers }
    );
  }

  getDomesticTransactionType(
    token: any,
    username: any,
    countryId = 0,
    agentType = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/domestic-transaction-type?CountryId=${countryId}&AgentType=${agentType}`,
      { headers: headers }
    );
  }

  getInternationalTransactionType(
    token: any,
    username: any,
    countryId = 0,
    agentType = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/international-transaction-type?CountryId=${countryId}&AgentType=${agentType}`,
      { headers: headers }
    );
  }

  getRebateCurrencyType(token: any, username: any): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/rebate-currency-type`,
      { headers: headers }
    );
  }

  addAgent(token: any, username: any, payload: any): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.post(
      `${environment.apiUrl}/api/master/manage-agent/add`,
      payload,
      { headers: headers }
    );
  }

  getAgentById(token: any, username: any, agentId = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/manage-agent/view?Id=${agentId}&ModuleID=20`,
      { headers: headers }
    );
  }

  editAgentById(agentId: any) {
    return this.http.get(
      `${environment.apiUrl}/api/master/agent/edit?AgentID=${agentId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  updateAgent(token: any, username: any, payload: any): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.patch(
      `${environment.apiUrl}/api/master/manage-agent/update`,
      payload,
      { headers: headers }
    );
  }
}
