import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { environment } from 'src/environments/environment';
import { Observable } from 'rxjs';
import { getCacheData } from '../utils/helper';

@Injectable({
  providedIn: 'root',
})
export class AllSendTransactionMisService {
  baseUrl = environment.apiUrl;

  constructor(private http: HttpClient) {}

  private getHeaders(): HttpHeaders {
    return new HttpHeaders({
      Authorization: getCacheData('admin_token'),
      Accept: 'application/json',
      username: getCacheData('username'),
    });
  }

  getRecipientCountryList(countryId: any = 0): Observable<any[]> {
    const headers = this.getHeaders();
    return this.http.get<any[]>(
      `${this.baseUrl}/api/master/reports/all-sent-trxn-report/rec-country?G_UserID=0&ReportType=0&CountryID=${countryId}`,
      { headers }
    );
  }

  getAgentListByCountry(countryId: any = 0): Observable<any[]> {
    const headers = this.getHeaders();
    return this.http.get<any[]>(
      `${this.baseUrl}/api/master/reports/all-sent-trxn-report/agent?CountryID=${countryId}`,
      { headers }
    );
  }

  getTransactionDetailGrid(
    fromDate: string,
    toDate: string,
    agentId: number,
    countryId: number
  ): Observable<any[]> {
    const headers = this.getHeaders();
    return this.http.get<any[]>(
      `${this.baseUrl}/api/master/reports/all-sent-trxn-report/detail/grid?FromDate=${fromDate}&ToDate=${toDate}&AgentID=${agentId}&CountryID=${countryId}`,
      { headers }
    );
  }

  getTransactionSummaryGrid(
    fromDate: string,
    toDate: string,
    agentId: number,
    countryId: number
  ): Observable<any[]> {
    const headers = this.getHeaders();
    return this.http.get<any[]>(
      `${this.baseUrl}/api/master/reports/all-sent-trxn-report/summary/grid?FromDate=${fromDate}&ToDate=${toDate}&AgentID=${agentId}&CountryID=${countryId}`,
      { headers }
    );
  }

  getStatusWiseTransactionSummaryGrid(
    fromDate: string,
    toDate: string,
    agentId: number,
    countryId: number
  ): Observable<any[]> {
    const headers = this.getHeaders();
    return this.http.get<any[]>(
      `${this.baseUrl}/api/master/reports/all-sent-trxn-report/status-wise-summary/grid?FromDate=${fromDate}&ToDate=${toDate}&AgentID=${agentId}&CountryID=${countryId}`,
      { headers }
    );
  }
}
