import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Router } from '@angular/router';
import { Observable } from 'rxjs';
import { environment } from 'src/environments/environment';
import { getCacheData } from '../utils/helper';

@Injectable({
  providedIn: 'root',
})
export class AuthService {
  url = environment.apiUrl;

  constructor(private router: Router, private http: HttpClient) {}

  get token() {
    return sessionStorage.getItem('admin_token');
  }

  getToken() {
    return this.token;
  }

  login(username: any, password): Observable<any> {
    return this.http.get(
      `${environment.apiUrl}/api/master/Login?username=${username}&password=${password}`
    );
  }

  userAlreadyLoginYes(userId: any, userName): Observable<any> {
    return this.http.get(
      `${environment.apiUrl}/api/master/user-already-login-yes?UserID=${userId}&UserName=${userName}`
    );
  }

  userAlreadyLoginNo(userId: any): Observable<any> {
    return this.http.get(
      `${environment.apiUrl}/api/master/user-already-login-no?UserID=${userId}`
    );
  }

  isAuthenticated(): boolean {
    return !!this.getToken();
  }

  logOut() {
    sessionStorage.clear();
    this.router.navigate(['/session-expired']);
  }

  userLogOut(): Observable<any> {
    return this.http.get(
      `${environment.apiUrl}/api/master/logout?UserID=${getCacheData(
        'G_UserID'
      )}&CurrentLogin_ID=${getCacheData('CurrentLogin_ID')}`
    );
  }
  get userName() {
    const username = getCacheData('user_email') || '';
    return username.split('@')[0];
  }

  getTodayDate(): string {
    return new Date().toISOString().split('T')[0]; // Get today's date in YYYY-MM-DD format
  }

  getMenuList() {
    return this.http.get(
      `${environment.apiUrl}/api/menu/all-menu?UserID=${getCacheData(
        'G_UserID'
      )}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }
}
