import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Router } from '@angular/router';
import { Observable } from 'rxjs';
import { environment } from 'src/environments/environment';

@Injectable({
  providedIn: 'root',
})
export class BankRatesService {
  url = environment.apiUrl;

  constructor(private router: Router, private http: HttpClient) {}

  getAllBankRates(token: any, username, countryId: any = 0, agentId: any = 0) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/agent-wise-rate/exchange-rate-bank-rate?countryId=${countryId}&agentId=${agentId}`,
      {
        headers: headers,
      }
    );
  }

  getReceivingCountry(token: any, username, userId: any = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/agent-wise-rate/receiving-country-dropdown?userId=${userId}
     `,
      {
        headers: headers,
      }
    );
  }

  getReceivingAgent(token: any, username, countryId: any = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/agent-wise-rate/receiving-agent-dropdown?countryId=${countryId}
     `,
      {
        headers: headers,
      }
    );
  }

  getReceivingCurrency(
    token: any,
    username,
    countryId: any = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/agent-wise-rate/insert-record/receiving-currency-list?countryID=${countryId}
     `,
      {
        headers: headers,
      }
    );
  }

  getAgentAccountList(
    token: any,
    username,
    countryId: any = 0,
    currencyId: any = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/agent-wise-rate/insert-record/agent-account-list?countryId=${countryId}&currencyId=${currencyId}
     `,
      {
        headers: headers,
      }
    );
  }

  getModeofPaymentList(
    token: any,
    username,
    agentId: any = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/agent-wise-rate/insert-record/mode-of-payment-list?AgentId=${agentId}
     `,
      {
        headers: headers,
      }
    );
  }

  addBankRates(token: any, username, payload: any): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.post(
      `${environment.apiUrl}/api/master/agent-wise-rate/exchange-rate-bank-rate
     `,
      payload,
      {
        headers: headers,
      }
    );
  }

  updateBankRates(token: any, username, payload: any): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.patch(
      `${environment.apiUrl}/api/master/agent-wise-rate/exchange-rate-bank-rate
     `,
      payload,
      {
        headers: headers,
      }
    );
  }
}
