import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { environment } from 'src/environments/environment';
import { getCacheData } from '../utils/helper';

@Injectable({
  providedIn: 'root'
})
export class BeneficiaryComplianceService {

  constructor(private http: HttpClient) {}

  approveBeneficiaryCompliance(remark: string, beneficiaryNo: string, gUserName: string): Observable<any> {
    const headers = this.getHeaders();

    const params = {
      Remark: remark,
      BeneficiaryNo: beneficiaryNo,
      GUserName: gUserName
    };

    return this.http.get(`${environment.apiUrl}/v1/api/complicance/beneficiary-complicance-release/approve`, { headers: headers, params: params });
  }

  viewBeneficiaryCompliance(beneficiaryNo: string, status: string): Observable<any> {
    const headers = this.getHeaders();

    const params = {
      BeneficiaryNo: beneficiaryNo,
      status: status
    };

    return this.http.get(`${environment.apiUrl}/v1/api/complicance/beneficiary-complicance-release/view`, { headers: headers, params: params });
  }

  getAllRecordsWithStatus(status: string): Observable<any> {
    const headers = this.getHeaders();

    return this.http.get(`${environment.apiUrl}/v1/api/complicance/beneficiary-complicance-release/all-record`, { headers: headers, params: { status: status } });
  }

  private getHeaders(): HttpHeaders {
    return new HttpHeaders({
      Authorization: getCacheData('admin_token'),
      Accept: 'application/json',
      username: getCacheData('username'),
    });
  }
}
