import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { StatementOfAccountService } from '../services/statement-of-account.service';

@Component({
  selector: 'app-statement-of-account',
  templateUrl: './statement-of-account.component.html',
  styleUrls: ['./statement-of-account.component.css'],
})
export class StatementOfAccountComponent implements OnInit {
  stateOfAccountForm: FormGroup;
  showTable: boolean = false;
  stateOfAccountData: any[] = [];
  agentAccounts: any[] = [];
  selectedAccountId: any;
  formSubmitted: boolean = false;
  isLoading: boolean = false;

  constructor(
    private fb: FormBuilder,
    private statementOfAccountService: StatementOfAccountService
  ) {}

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
  ngOnInit(): void {
    const currentStartDate = new Date(new Date().toLocaleString("en-US", { timeZone: "Asia/Riyadh" })).toISOString().substring(0, 10);

    const currentEndDate = new Date(new Date().toLocaleString("en-US", { timeZone: "Asia/Riyadh" })).toISOString().substring(0, 10);

    this.stateOfAccountForm = this.fb.group({
      startDate: [currentStartDate, Validators.required],
      endDate: [currentEndDate, Validators.required],
      selectedAgentAccount: [null, Validators.required],
    });
    this.loadAgentAccounts();
  }

  loadAgentAccounts(): void {
    this.statementOfAccountService.getUSDStatementOfAccountAgent(0).subscribe(
      (data: any[]) => {
        this.agentAccounts = data;
      },
      (error: any) => {
        console.error('Error fetching agent accounts:', error);
      }
    );
  }

  fetchData(): void {
    this.formSubmitted = true;
    if (this.stateOfAccountForm.valid) {
      const { startDate, endDate } = this.stateOfAccountForm.value;
      if (!startDate) {
        alert('Please Select Start Date.');
        return;
      }
      if (!endDate) {
        alert('Please Select End Date.');
        return;
      }

      if (!this.selectedAccountId) {
        alert('Please Select Agent Account.');
        return;
      }
      this.isLoading = true;
      this.statementOfAccountService
        .getUSDStatementOfAccountGrid(
          0,
          this.selectedAccountId,
          startDate,
          endDate
        )
        .subscribe(
          (data: any[]) => {
            if (data?.length == 0) {
              this.isLoading = false;
              alert('No data found.');
              return;
            }
            this.stateOfAccountData = data;
            this.showTable = true;
            this.isLoading = false;
          },
          (error: any) => {
            console.error('Error fetching data:', error);
            this.isLoading = false;
          }
        );
    }
  }

  updateSelectedAccount(accountId: string) {
    this.selectedAccountId = accountId;
  }

  isInvalid(controlName: string): boolean {
    const control = this.stateOfAccountForm.get(controlName);
    return control.invalid && (control.dirty || control.touched);
  }
}
