import { Component, OnInit } from '@angular/core';
import { TreasureReportService } from '../services/treasure-report.service';
import { NgForm } from '@angular/forms';
import * as XLSX from 'xlsx';
@Component({
  selector: 'app-treasury-report',
  templateUrl: './treasury-report.component.html',
  styleUrls: ['./treasury-report.component.css']
})
export class TreasuryReportComponent implements OnInit {
  treasuryReports: any[] = [];
  totals: any = {};
  totalsSecondTable: any = {};
  isLoading: boolean = false;
  selectedFileFormat: any = '1';
  selectDate: string = '';
  selectedCustomerType: string = 'A'; // Default to 'ALL'

  constructor(private treasureReportService: TreasureReportService) {}

  ngOnInit() {
    this.initializeDate();
  }

  initializeDate(): void {
    const today = new Date();
    const yyyy = today.getFullYear();
    const mm = String(today.getMonth() + 1).padStart(2, '0'); // Months are zero-based
    const dd = String(today.getDate()).padStart(2, '0');
    this.selectDate = `${yyyy}-${mm}-${dd}`;
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  formatDate(date: string): string {
    const d = new Date(date);
    const month = ('0' + (d.getMonth() + 1)).slice(-2); // months are zero-based
    const day = ('0' + d.getDate()).slice(-2);
    const year = d.getFullYear();
    return `${month}/${day}/${year}`;
  }
  submitForm(form: NgForm) {
    this.isLoading=true
    const { customerType, selectDate } = form.value;

  const  formateddate= this.formatDate(selectDate)

    this.treasureReportService.getTreasuryReportList(customerType, formateddate).subscribe(
      response => {
        this.isLoading=false

        console.log('Report data:', response);
        this.treasuryReports = response; // Assuming response is the array of reports
        this.calculateTotals();
        this.calculateTotalsSecondTable();
      },
      error => {
        console.error('Error fetching treasury reports:', error);
        this.isLoading=false
      }
    );
  }
  exportToExcel() {
    if (this.treasuryReports && this.treasuryReports.length > 0) {
      const firstTableData = this.treasuryReports.map(report => ({
        CCY: report.treasuryTblFirst[0]?.CCY,
        'Volume DTD (SAR)': report.treasuryTblFirst[0]?.VDTD,
        'Volume MTD (SAR)': report.treasuryTblFirst[0]?.VMTD,
        'Volume YTD (SAR)': report.treasuryTblFirst[0]?.VYTD,
        'FX P/L DTD (USD)': report.treasuryTblFirst[0]?.FXDTD,
        'FX P/L MTD (USD)': report.treasuryTblFirst[0]?.FXMTD,
        'FX P/L YTD (USD)': report.treasuryTblFirst[0]?.FXYTD,
        'Net Fees DTD (USD)': report.treasuryTblFirst[0]?.NETDTD,
        'Net Fees MTD (USD)': report.treasuryTblFirst[0]?.NETMTD,
        'Net Fees YTD (USD)': report.treasuryTblFirst[0]?.NETYTD,
        'Rebate DTD (USD)': report.treasuryTblFirst[0]?.REBDTD,
        'Rebate MTD (USD)': report.treasuryTblFirst[0]?.REBMTD,
        'Rebate YTD (USD)': report.treasuryTblFirst[0]?.REBYTD,
        'Total P/L DTD (USD)': report.treasuryTblFirst[0]?.TOTDTD,
        'Total P/L MTD (USD)': report.treasuryTblFirst[0]?.TOTMTD,
        'Total P/L YTD (USD)': report.treasuryTblFirst[0]?.TOTYTD
      }));
      
      const secondTableData = this.treasuryReports.flatMap(report =>
        report.treasuryTblSecond.map(item => ({
          CCY: item.TCCY,
          'Volume Staff (SAR)': item.VSTAFF,
          'Volume Client (SAR)': item.VCLIENT,
          'Sum of SAIB Earnings Staff (USD)': item.FXSTAFF,
          'Sum of SAIB Earnings Client (USD)': item.FXCLIENT,
          'SAIB Net Fees Staff (USD)': item.FEESTAFF,
          'SAIB Net Fees Client (USD)': item.FEECLIENT,
          'Sum of Rebate Income Staff (USD)': item.REBSTAFF,
          'Sum of Rebate Income Client (USD)': item.REBCLIENT,
          'Staff Total P/L DTD (USD)': item.STAFFDTD,
          'Staff Total P/L YTD (USD)': item.STAFFYTD,
          'Client Total P/L DTD (USD)': item.CLIENTDTD,
          'Client Total P/L YTD (USD)': item.CLIENTYTD
        }))
      );

      // Adding total row for first table
      firstTableData.push({
        CCY: 'Total',
        'Volume DTD (SAR)': this.totals.VDTD,
        'Volume MTD (SAR)': this.totals.VMTD,
        'Volume YTD (SAR)': this.totals.VYTD,
        'FX P/L DTD (USD)': this.totals.FXDTD,
        'FX P/L MTD (USD)': this.totals.FXMTD,
        'FX P/L YTD (USD)': this.totals.FXYTD,
        'Net Fees DTD (USD)': this.totals.NETDTD,
        'Net Fees MTD (USD)': this.totals.NETMTD,
        'Net Fees YTD (USD)': this.totals.NETYTD,
        'Rebate DTD (USD)': this.totals.REBDTD,
        'Rebate MTD (USD)': this.totals.REBMTD,
        'Rebate YTD (USD)': this.totals.REBYTD,
        'Total P/L DTD (USD)': this.totals.TOTDTD,
        'Total P/L MTD (USD)': this.totals.TOTMTD,
        'Total P/L YTD (USD)': this.totals.TOTYTD
      });

      // Adding total row for second table
      secondTableData.push({
        CCY: 'Total',
        'Volume Staff (SAR)': this.totalsSecondTable.VSTAFF,
        'Volume Client (SAR)': this.totalsSecondTable.VCLIENT,
        'Sum of SAIB Earnings Staff (USD)': this.totalsSecondTable.FXSTAFF,
        'Sum of SAIB Earnings Client (USD)': this.totalsSecondTable.FXCLIENT,
        'SAIB Net Fees Staff (USD)': this.totalsSecondTable.FEESTAFF,
        'SAIB Net Fees Client (USD)': this.totalsSecondTable.FEECLIENT,
        'Sum of Rebate Income Staff (USD)': this.totalsSecondTable.REBSTAFF,
        'Sum of Rebate Income Client (USD)': this.totalsSecondTable.REBCLIENT,
        'Staff Total P/L DTD (USD)': this.totalsSecondTable.STAFFDTD,
        'Staff Total P/L YTD (USD)': this.totalsSecondTable.STAFFYTD,
        'Client Total P/L DTD (USD)': this.totalsSecondTable.CLIENTDTD,
        'Client Total P/L YTD (USD)': this.totalsSecondTable.CLIENTYTD
      });

      const worksheet1: XLSX.WorkSheet = XLSX.utils.json_to_sheet(firstTableData);
      const worksheet2: XLSX.WorkSheet = XLSX.utils.json_to_sheet(secondTableData);
      const workbook: XLSX.WorkBook = {
        Sheets: { 'First Table': worksheet1, 'Second Table': worksheet2 },
        SheetNames: ['First Table', 'Second Table']
      };

      XLSX.writeFile(workbook, 'Treasury_Report.xlsx');
    }
  }
  
  calculateTotals() {
    this.totals = this.treasuryReports.reduce((acc, report) => {
      const data = report.treasuryTblFirst[0];
      acc.VDTD = (acc.VDTD || 0) + data.VDTD;
      acc.VMTD = (acc.VMTD || 0) + data.VMTD;
      acc.VYTD = (acc.VYTD || 0) + data.VYTD;
      acc.FXDTD = (acc.FXDTD || 0) + data.FXDTD;
      acc.FXMTD = (acc.FXMTD || 0) + data.FXMTD;
      acc.FXYTD = (acc.FXYTD || 0) + data.FXYTD;
      acc.NETDTD = (acc.NETDTD || 0) + data.NETDTD;
      acc.NETMTD = (acc.NETMTD || 0) + data.NETMTD;
      acc.NETYTD = (acc.NETYTD || 0) + data.NETYTD;
      acc.REBDTD = (acc.REBDTD || 0) + data.REBDTD;
      acc.REBMTD = (acc.REBMTD || 0) + data.REBMTD;
      acc.REBYTD = (acc.REBYTD || 0) + data.REBYTD;
      acc.TOTDTD = (acc.TOTDTD || 0) + data.TOTDTD;
      acc.TOTMTD = (acc.TOTMTD || 0) + data.TOTMTD;
      acc.TOTYTD = (acc.TOTYTD || 0) + data.TOTYTD;
      return acc;
    }, {});
  }

  calculateTotalsSecondTable() {
    this.totalsSecondTable = this.treasuryReports.reduce((acc, report) => {
      report.treasuryTblSecond.forEach(item => {
        acc.VSTAFF = (acc.VSTAFF || 0) + item.VSTAFF;
        acc.VCLIENT = (acc.VCLIENT || 0) + item.VCLIENT;
        acc.FXSTAFF = (acc.FXSTAFF || 0) + item.FXSTAFF;
        acc.FXCLIENT = (acc.FXCLIENT || 0) + item.FXCLIENT;
        acc.FEESTAFF = (acc.FEESTAFF || 0) + item.FEESTAFF;
        acc.FEECLIENT = (acc.FEECLIENT || 0) + item.FEECLIENT;
        acc.REBSTAFF = (acc.REBSTAFF || 0) + item.REBSTAFF;
        acc.REBCLIENT = (acc.REBCLIENT || 0) + item.REBCLIENT;
        acc.STAFFDTD = (acc.STAFFDTD || 0) + item.STAFFDTD;
        acc.STAFFYTD = (acc.STAFFYTD || 0) + item.STAFFYTD;
        acc.CLIENTDTD = (acc.CLIENTDTD || 0) + item.CLIENTDTD;
        acc.CLIENTYTD = (acc.CLIENTYTD || 0) + item.CLIENTYTD;
      });
      return acc;
    }, {});
  }


  toFixed(value: number): string {
    return value.toFixed(2);
  }
}
