import { Component, Renderer2, TemplateRef, ViewChild } from '@angular/core';
import { ViewTransactionStatusForAgentService } from '../view-transaction-status-for-agent.service';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { AuthService } from '../services/auth.service';
import { getCacheData } from '../utils/helper';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-view-transaction-status-for-agent',
  templateUrl: './view-transaction-status-for-agent.component.html',
  styleUrls: ['./view-transaction-status-for-agent.component.css'],
})
export class ViewTransactionStatusForAgentComponent {
  bsModalRef: BsModalRef;
  @ViewChild('viewLog') viewLogModal;
  @ViewChild('viewTransactionReceipt') viewTransactionReceiptModal;
  bsTransactionReceiptModalRef: BsModalRef;

  LogData: any;
  CountryID: any = 0;
  CountryDropdown: any;
  AgentDropdown: any;
  StatusDropDown: any;
  AgentBranchDropDown: any;
  DataList: any = [];
  AgentID: any = -1;
  AgentBranchID: any = 'ALL';
  StatusId: any = -1;
  fromDate: any;
  toDate: any;
  TransactionNumber: any;
  isLoading: boolean = false;
  receiptData: any = {};

  constructor(
    private modalService: BsModalService,
    private ViewTransactionStatusForAgentSvc: ViewTransactionStatusForAgentService,
    private authSvc: AuthService,
    private toastrSvc: ToastrService
  ) { }

  ngOnInit(): void {
    this.getCountry();
    this.fromDate = this.authSvc.getTodayDate();
    this.toDate = this.authSvc.getTodayDate();
  }
  getCountry() {
    this.ViewTransactionStatusForAgentSvc.getCountryList().subscribe((res) => {
      this.CountryDropdown = res;
      this.CountryID = res?.[0]?.CountryId;
    });
  }

  onSelectCountry(CountryID) {
    this.CountryID = CountryID;

    this.getAgent(CountryID);
    this.getStatus();
  }

  getAgent(CountryID) {
    this.ViewTransactionStatusForAgentSvc.getAgentList(CountryID).subscribe(
      (res) => {
        this.AgentDropdown = res;
      }
    );
  }

  OnSelectAgent(AgentID) {
    this.AgentID = AgentID;
    this.getAgentbranch(AgentID);
  }

  getAgentbranch(AgentID) {
    this.ViewTransactionStatusForAgentSvc.getAgentBranchList(AgentID).subscribe(
      (res) => {
        this.AgentBranchDropDown = res;
      }
    );
  }

  onSelectAgentbranch(AgentBranchID) {
    this.AgentBranchID = AgentBranchID;
  }

  getStatus() {
    this.ViewTransactionStatusForAgentSvc.getStatusList().subscribe((res) => {
      this.StatusDropDown = res;
    });
  }

  onSelectStatus(StatusId) {
    this.StatusId = StatusId;
  }

  getBranchName(agent_id) {
    for (var i = 0; i < this.AgentBranchDropDown?.length; i++) {
      if (this.AgentBranchDropDown[i].AgentBranch_ID == agent_id) {
        return this.AgentBranchDropDown[i].AgentBranch_Name;
      }
    }
    return 'All';
  }

  getTransactionReport() {
    if (!this.TransactionNumber) {
      alert('Please Enter Transaction Number.');
      return;
    }
    this.ViewTransactionStatusForAgentSvc.getTransactionReport(
      this.TransactionNumber
    ).subscribe((res: any) => {
      if (res?.length == 0) {
        alert('No data found.');
        return;
      }
      this.DataList = res;
    });
  }

  getTransactionDetail() {
    if (!this.fromDate || !this.toDate) {
      alert('Please Select From and To Dates.');
      return;
    }
    const payload = {
      FromDate: this.fromDate,
      ToDate: this.toDate,
      AgentID: Number(this.AgentID),
      CountryID: Number(this.CountryID),
      StatusID: Number(this.StatusId),
      AgentBranchID: String(this.AgentBranchID),
    };
    this.isLoading = true;
    this.ViewTransactionStatusForAgentSvc.transactionDetail(payload).subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          return;
        }
        this.DataList = res;
        this.isLoading = false;
      },
      error: (err) => {
        this.isLoading = false;
        // alert(err?.error?.message || 'Something went wrong');
        this.toastrSvc.error(err?.error?.message);
      },
      complete: () => {
        this.isLoading = false;
      },
    });
  }

  filter() {
    if (!this.TransactionNumber) {
      alert('Please Enter Transaction Number.');
      return;
    }
    const payload = {
      G_UserGroup: getCacheData('G_UserGroup'),
      SubUserGroup_Id: getCacheData('SubUserGroup_Id'),
      IsHeadOffice: 'True',
      TransactionNumber: this.TransactionNumber,
      AgentID: Number(this.AgentID),
      AgentBranchID: Number(this.AgentBranchID),
    };
    this.isLoading = true;
    this.ViewTransactionStatusForAgentSvc.transactionNumberDetail(
      payload
    ).subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          return;
        }
        this.DataList = res;
        this.isLoading = false;
      },
      error: (err) => {
        this.isLoading = false;
        // alert(err?.error?.message || 'Something went wrong');
        this.toastrSvc.error(err?.error?.message);
      },
      complete: () => {
        this.isLoading = false;
      },
    });
  }

  openModal(template: TemplateRef<any>) {
    this.bsModalRef = this.modalService.show(template, {
      class: 'modal-lg',
    });
  }

  getlog(TransactionNumber: any) {
    this.ViewTransactionStatusForAgentSvc.getLog(TransactionNumber).subscribe(
      (res) => {
        this.openModal(this.viewLogModal);
        this.LogData = res;
      }
    );
  }

  getTransactionNumberDetail(item) {
    const trnNo = item?.Random_No ? item?.Random_No : item?.SRTRNo;
    this.ViewTransactionStatusForAgentSvc.getTransactionReport(trnNo).subscribe(
      (res: any) => {
        if (res?.[0]?.IsDuplicate == true) {
          alert('No data found.');
          return;
        }
        this.receiptData = res?.[0];
        this.openTransactionReceiptModal(this.viewTransactionReceiptModal);
      }
    );
  }

  openTransactionReceiptModal(template: TemplateRef<any>) {
    this.bsTransactionReceiptModalRef = this.modalService.show(template, {
      class: 'modal-lg',
    });
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
